set_shadow_heap_left

Function set_shadow_heap_left 

#[unsafe(export_name = "__asan_set_shadow_fa")]
pub unsafe extern "C-unwind" fn set_shadow_heap_left( address: VirtualAddress, count: usize, )
Available on crate feature full only.
Marks count entries in the shadow map starting at address as “heap left redzone”

Safety

address must be an address in the shadow map